@extends('aud::password.layout')

@section('title', 'AuthStack &ndash; Reset Password')

@section('content')
    <h2>Please enter and confirm your new password.</h2>

    @if (Session::has('passwordError'))
        <div class="alert alert-error">
            <ul>
                <li>{!! Session::get('passwordError') !!}</li>
            </ul>
        </div>
    @endif

    <form method="POST" action="{{ route('aud.password.update') }}">

        {{ csrf_field() }}

        <input type="hidden" name="token" value="{{ $token }}">

        <div class="form-group row">
            <label for="password"
                   class="col-md-4 col-form-label text-md-right">{{ __('Password') }}</label>

            <div class="col-md-6">
                <input id="password" type="password"
                       class="form-control"
                       name="password" required>
            </div>
        </div>

        <div class="form-group row">
            <label for="password-confirm"
                   class="col-md-4 col-form-label text-md-right">{{ __('Confirm Password') }}</label>
            <div class="col-md-6">
                <input id="password-confirm" type="password"
                       class="form-control"
                       name="password_confirmation" required>
            </div>
        </div>

        <div class="form-group row mb-0">
            <div class="col-md-6 offset-md-4">
                <button type="submit" class="btn btn-primary">
                    {{ __('Reset Password') }}
                </button>
            </div>
        </div>
    </form>
@endsection